#!/bin/sh

if [[ $# -eq 0 ]] ; then
  echo "Usage:"
  echo "  $0 [OPTIONS] RPM1 RPM2 ..."
  echo "Options:"
  echo "  --update-only: only update the installed RPM"
  echo "  --update: update or install the RPM"
  echo "  (none): only install RPM if not installed yet"
  echo "Example:"
  echo "  $0 graphviz nodejs"
  exit 1
fi

PATH=sh/EPAGES_RELEASE/var/epages:/var/epages:$PATH

. functions.sh

started_by_rpm $$ && exit 0

if [[ $KERNEL = ${KERNEL%s} && $EPAGES_KERNEL = ${EPAGES_KERNEL%s} ]] ; then
  INSTALLER=yum ; YES=-y ; unset ZES
else
  INSTALLER=zypper ; ZES=-y ; unset YES
  zypper mr -d epages-setup
fi

unset DISABLE_AFTER ENABLE_AFTER
for i in $ENABLE_REPO ; do
  if [[ $INSTALLER = yum ]] ; then
    YES="$YES --enablerepo $i"
  else
    ZES="$ZES -r $i"
    zypper lr $i > /tmp/$$.pid1
    zypper mr -e $i
    zypper lr $i > /tmp/$$.pid2
    cmp -s /tmp/$$.pid1 /tmp/$$.pid2 || DISABLE_AFTER="$DISABLE_AFTER $i"
    rm -f /tmp/$$.pid1 /tmp/$$.pid2
  fi
done
for i in $DISABLE_REPO ; do
  if [[ $INSTALLER = yum ]] ; then
    YES="$YES --disablerepo $i"
  else
    zypper lr $i > /tmp/$$.pid1
    zypper mr -d $i
    zypper lr $i > /tmp/$$.pid2
    cmp -s /tmp/$$.pid1 /tmp/$$.pid2 || ENABLE_AFTER="$ENABLE_AFTER $i"
    rm -f /tmp/$$.pid1 /tmp/$$.pid2
  fi
done

case $1 in
  --update-only) DO=update ; shift ;;
  --update) DO=install_or_update ; shift ;;
  *) DO=install ;;
esac

for RPM in $@ ; do
  if rpm --quiet -q $RPM ; then
    [[ $DO = install ]] && continue
    if [[ $INSTALLER = zypper ]] ; then
      # workaround: 'zypper update $RPM' does not work :(
      zypper list-updates | awk "/ $RPM /{exit 123}"
      [[ $? = 123 ]] || continue # up-to-date
      rpm -e --nodeps $RPM
      DO=install
    else
      DO=update
    fi
  else
    [[ $DO = update ]] && continue
    DO=install
  fi
  echo "$INSTALLER $YES $DO $ZES $RPM"
  eval $INSTALLER $YES $DO $ZES $RPM || exit 1
done

if [[ $INSTALLER = zypper ]] ; then
  for i in $DISABLE_AFTER ; do
    zypper mr -d $i
  done
  for i in $ENABLE_AFTER ; do
    zypper mr -e $i
  done
fi

exit 0
